@@ -2,7 +2,24 @@ package HTTP::Proxy::BodyFilter::tags;
 
 use strict;
 use Carp;
-use base qw( HTTP::Proxy::BodyFilter );
+use HTTP::Proxy::BodyFilter;
+use vars qw( @ISA );
+@ISA = qw( HTTP::Proxy::BodyFilter );
+
+sub filter {
+    my ( $self, $dataref, $message, $protocol, $buffer ) = @_;
+    return if not defined $buffer;    # last "tags"
+
+    my $idx = rindex( $$dataref, '<' );
+    if ( $idx > rindex( $$dataref, '>' ) ) {
+        $$buffer = substr( $$dataref, $idx );
+        $$dataref = substr( $$dataref, 0, $idx );
+    }
+}
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -28,18 +45,22 @@ HTTP::Proxy::BodyFilter::tags - A filter that outputs only complete tags
 The HTTP::Proxy::BodyFilter::tags filter makes sure that the next filter
 in the filter chain will only receive complete tags.
 
-=cut
+=head1 METHOD
 
-sub filter {
-    my ( $self, $dataref, $message, $protocol, $buffer ) = @_;
-    return if not defined $buffer;    # last "tags"
+This class defines a single method, that is called automatically:
 
-    my $idx = rindex( $$dataref, '<' );
-    if ( $idx > rindex( $$dataref, '>' ) ) {
-        $$buffer = substr( $$dataref, $idx );
-        $$dataref = substr( $$dataref, 0, $idx );
-    }
-}
+=over 4
+
+=item filter()
+
+Buffer incomplete tags to ensure that subsequent filters will only
+receive complete HTML tags.
+
+=back
+
+=head1 SEE ALSO
+
+L<HTTP::Proxy>, L<HTTP::Proxy::BodyFilter>.
 
 =head1 AUTHOR
 
@@ -47,7 +68,7 @@ Philippe "BooK" Bruhat, E<lt>book@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003-2004, Philippe Bruhat
+Copyright 2003-2005, Philippe Bruhat.
 
 =head1 LICENSE
 
@@ -56,4 +77,3 @@ the same terms as Perl itself.
 
 =cut
 
-1;
